==> library1.4.1.tar.bz2: library/berezh/editform.php <==
<?php
  ///////////////////////////////////////////////////
  //Карпухин Павел
  //2010 (C)
  ///////////////////////////////////////////////////
  require_once "../utils/chlang.php";

  $title=$titlepage = $TEXT['menu-btn26-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  $button = $TEXT['btn_save'];
  $action = "edit.php";

  if(strlen($_GET['obr_id'])>5) {puterror($result2['skin'],$TEXT['error-obr6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['obr_id'] = rep($_GET['obr_id']);

  $old_obr_id = $_GET['obr_id'];

  $query10 = "SELECT * FROM `tbl_obraschenie` WHERE `obr_id`='".$_GET['obr_id']."' ";
  $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl18']); require_once "../utils/bottom_adm.php"; exit();}
      $result_obr = mysqli_fetch_array($result10);
         $kachestvo = $result_obr['kachestvo'];
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center">
<tr><td class="inform"><?php echo $TEXT['global-edit']; ?>:</td><td><input size=50 maxlength=127 type=text name=kachestvo value='<?php echo $kachestvo; ?>'></td></tr>
<tr><td></td><td>
<input class="button2" type=submit value='<?php echo $button; ?>' />
<input type=hidden name=obr_id value='<?php echo $old_obr_id; ?>' />
</td></tr>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>

==> library1.19.1.tar.bz2: library/berezh/editform.php <==
<?php
  ///////////////////////////////////////////////////
  //Карпухин Павел
  //2010 (C)
  ///////////////////////////////////////////////////
  require_once "../utils/chlang.php";

  $title=$titlepage = $TEXT['menu-btn26-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  $button = $TEXT['btn_save'];
  $action = "edit.php";

  if(strlen($_GET['obr_id'])>5) {puterror($result2['skin'],$TEXT['error-obr6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['obr_id'] = rep($_GET['obr_id']);

  $old_obr_id = $_GET['obr_id'];

  $query10 = "SELECT * FROM `tbl_obraschenie` WHERE `obr_id`='".$_GET['obr_id']."' ";
  $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl18']); require_once "../utils/bottom_adm.php"; exit();}
      $result_obr = mysqli_fetch_array($result10);
         $kachestvo = $result_obr['kachestvo'];
?>
<form enctype="multipart/form-data" action="<?php echo $action; ?>" method="post">
<table align="center">
<tr><td class="inform"><?php echo $TEXT['global-edit']; ?>:</td><td><input size="50" maxlength="127" type="text" name="kachestvo" value="<?php echo $kachestvo; ?>"></td></tr>
<tr><td></td><td>
<input class="button2" type="submit" value="<?php echo $button; ?>" />
<input type="hidden" name="obr_id" value="<?php echo $old_obr_id; ?>" />
</td></tr>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>
